@@ -4,7 +4,6 @@ use parent 'Device::Modbus::ADU';
 use Carp;
 use strict;
 use warnings;
-use v5.10;
 
 sub id {
     my ($self, $value) = @_;
@@ -26,10 +25,17 @@ sub length {
     return $self->{length};
 }
 
+# Modbus TCP states unit number is 0xFF by default 
+sub unit {
+    my $self = shift;
+    $_[0] = 0xFF unless exists $self->{unit} || defined $_[0];
+    return $self->SUPER::unit(@_);
+}    
+
 sub binary_message {
     my $self = shift;
     croak "Please include a unit number in the ADU."
-        unless $self->{unit};
+        unless $self->unit;
     my $header = $self->build_header;
     my $pdu    = $self->message->pdu();
     return $header . $pdu;
